@@ -14,7 +14,7 @@
 
 import os
 
-#~ execfile(os.path.join(os.path.dirname(__file__),'setup_info.py'))
-execfile(os.path.join(os.path.dirname(__file__),'..','setup_info.py'))
+execfile(os.path.join(os.path.dirname(__file__),'setup_info.py'))
+#~ execfile(os.path.join(os.path.dirname(__file__),'..','setup_info.py'))
 __version__ = SETUP_INFO['version']
 
