@@ -177,6 +177,50 @@ def unused_coachings(p,type,coach1,coach2,coached_from,coached_until=None):
 
 
 def objects():
+    
+    calendar = Instantiator('cal.Calendar').build
+    #~ yield calendar(**babel_values('name',
+          #~ de=u"Klientengespräche intern",
+          #~ fr=u"Rencontres internes avec client",
+          #~ en=u"Internal meetings with client",
+          #~ ))
+    yield calendar(color=1,**babel_values('name',
+          de=u"Klientengespräche extern",
+          fr=u"Rencontres client externes",
+          en=u"External meetings with client",
+          ))
+    
+    yield calendar(color=4,**babel_values('name',
+          de=u"Versammlung intern",
+          fr=u"Réunions internes",
+          en=u"Internal meetings",
+          ))
+    
+    yield calendar(color=8,**babel_values('name',
+          de=u"Versammlung extern",
+          fr=u"Réunions externes",
+          en=u"External meetings",
+          ))
+          
+    yield calendar(color=12,
+        #~ invite_team_members=True,email_template='Team.eml.html',
+        email_template='Team.eml.html',
+        **babel_values('name',
+          de=u"Team-Besprechungen",
+          fr=u"Coordinations en équipe",
+          en=u"Team Meetings",
+          ))
+    #~ yield etype(**babel_values('name',
+          #~ de=u"Erstgespräch",
+          #~ fr=u"Première rencontre",
+          #~ en=u"First meeting",
+          #~ ))
+    #~ yield etype(**babel_values('name',
+          #~ de=u"Auswertungsgespräch",
+          #~ fr=u"Évaluation",
+          #~ en=u"Evaluation",
+          #~ ))
+    
   
     sector = Instantiator(jobs.Sector).build
     for ln in SECTORS_LIST.splitlines():
@@ -554,7 +598,7 @@ def objects():
     #~ yield users.Membership(user=caroline,group=ug_asd)
     
     # id must be 1 (see isip.ContactBase.person_changed
-    yield pcsw.CoachingType(id=1,**babel_values('name',
+    yield pcsw.CoachingType(id=isip.COACHINGTYPE_ASD,**babel_values('name',
         de="ASD (Allgemeiner Sozialdienst)",
         nl="ASD (Algemene Sociale Dienst)",
         fr="SSG (Service social général)",
@@ -562,10 +606,10 @@ def objects():
         )) 
     
     #~ caroline = users.User.objects.get(username="caroline")
-    caroline.coaching_type_id = 1
+    caroline.coaching_type_id = isip.COACHINGTYPE_ASD
     caroline.save()
     
-    DSBE = pcsw.CoachingType(id=2,**babel_values('name',
+    DSBE = pcsw.CoachingType(id=isip.COACHINGTYPE_DSBE,**babel_values('name',
         de="DSBE (Dienst für Sozial-Berufliche Eingliederung)",
         fr="Service intégration",
         en="Integration service",
@@ -587,8 +631,6 @@ def objects():
         yield users.Team(**babelkw('name',**field2kw(obj,'name')))
     
     
-    
-    
     #~ USERS = Cycler(root,melanie,hubert,alicia)
     AGENTS = Cycler(melanie,hubert,alicia)
     COACHINGTYPES = Cycler(pcsw.CoachingType.objects.all())
