@@ -379,7 +379,7 @@ The raw XML response received.
 
     #~ send_action = ExecuteRequest()
     #~ print_action = mixins.DirectPrintAction(required=dict(states=['ok','warnings']))
-    print_action = mixins.DirectPrintAction()
+    do_print = mixins.DirectPrintAction()
     
     
     #~ def save(self,*args,**kw):
