@@ -68,7 +68,8 @@ def rangefmt(r):
 
 cal = dd.resolve_app('cal')
 
-COACHINGTYPE_ASD = 1          
+COACHINGTYPE_ASD = 1
+COACHINGTYPE_DSBE = 2
 
 
 #~ class IntegTable(dd.Table):
@@ -133,7 +134,8 @@ class ExamPolicy(dd.BabelNamed,cal.RecurrenceSet):
         verbose_name = _("Examination Policy")
         verbose_name_plural = _('Examination Policies')
         
-    hidden_columns = 'summary description start_date start_time end_date end_time'
+    #~ hidden_columns = 'summary description start_date start_time end_date end_time'
+    hidden_columns = 'start_date start_time end_date end_time'
     
         
 
@@ -145,7 +147,7 @@ class ExamPolicies(dd.Table):
     id name
     # summary start_date end_date
     # description
-    every every_unit calendar
+    max_occurences every every_unit calendar
     isip.ContractsByPolicy    
     jobs.ContractsByPolicy    
     """
@@ -495,21 +497,14 @@ add('20', _("Active"),'active')
 add('30', _("Ended"),'ended')
 add('40', _("Signed"),'signed')
 
-
 class ContractBaseTable(dd.Table):
-    parameters = dict(
+    parameters = dd.ObservedPeriod(
         user = dd.ForeignKey(settings.SITE.user_model,blank=True),
         #~ show_past = models.BooleanField(_("past contracts"),default=True),
         #~ show_active = models.BooleanField(_("active contracts"),default=True),
         #~ show_coming = models.BooleanField(_("coming contracts"),default=True),
         #~ today = models.DateField(_("on"),blank=True,default=datetime.date.today),
       
-        start_date = models.DateField(_("Period from"),
-            blank=True,null=True,
-            help_text="""Date début de la période observée"""),
-        end_date = models.DateField(_("until"),
-            blank=True,null=True,
-            help_text="""Date fin de la période observée"""),
         observed_event = ContractEvents.field(blank=True,default=ContractEvents.active),
       
         ending_success = dd.YesNo.field(_("Successfully ended"),
@@ -525,7 +520,7 @@ class ContractBaseTable(dd.Table):
     
     params_layout = """
     user type start_date end_date observed_event
-    ending_success ending
+    company ending_success ending
     """
     params_panel_hidden = True
     
@@ -596,8 +591,14 @@ class ContractBaseTable(dd.Table):
         for t in super(ContractBaseTable,self).get_title_tags(ar):
             yield t
             
-        if ar.param_values.observed_event:
-            yield unicode(ar.param_values.observed_event)
+        pv = ar.param_values
+        if pv.start_date is None or pv.end_date is None:
+            period = None
+        else:
+            oe = pv.observed_event
+            if oe is not None:
+                yield "%s %s-%s" % (unicode(oe.text),dd.dtos(pv.start_date), dd.dtos(pv.end_date))
+            
         if ar.param_values.company:
             yield unicode(ar.param_values.company)
             
