@@ -396,8 +396,7 @@ class AvailableCoaches(users.Users):
                 #~ total_weight += faculty_weight(user,None)
             #~ else:
                 #~ logger.info("20120928 AvailableCoaches.get_data_rows : no for_client")
-            user.new_clients = NewClients.request(
-              ar.ui,param_values=dict(
+            user.new_clients = NewClients.request(param_values=dict(
                 coached_by=user,
                 new_since=ar.param_values.since))
                 
@@ -433,11 +432,11 @@ class AvailableCoaches(users.Users):
     @dd.requestfield(_("Primary clients"))
     def primary_clients(self,obj,ar):
         #~ return pcsw.ClientsByCoach1.request(ar.ui,master_instance=obj)
-        return pcsw.CoachingsByUser.request(ar.ui,master_instance=obj)
+        return pcsw.CoachingsByUser.request(master_instance=obj)
         
     #~ @dd.requestfield(_("Active clients"))
     #~ def active_clients(self,obj,ar):
-        #~ return pcsw.IntegClients.request(ar.ui,param_values=dict(coached_by=obj,only_active=True))
+        #~ return pcsw.IntegClients.request(param_values=dict(coached_by=obj,only_active=True))
         
     @dd.requestfield(_("New Clients"))
     def new_clients(self,obj,ar):
@@ -514,7 +513,7 @@ nicht mehr angezeigt."""
         return super(AssignCoach,self).get_action_permission(ar,obj,state)
         #~ return super(AssignCoach,self).get_row_permission(ar,state,ba)
         
-    def run(self,obj,ar,**kw):
+    def run_from_ui(self,obj,ar,**kw):
         """
         Assign a coach to a newcomer.
         """
@@ -612,7 +611,7 @@ class AvailableCoachesByClient(AvailableCoaches):
                 #~ r = outbox.Recipient(mail=m,**rec)
                 #~ r.full_clean()
                 #~ r.save()
-            #~ m.send_mail.run(m,ar)
+            #~ m.send_mail.run_from_ui(m,ar)
             #~ interactive = (ar.get_user().profile.office_level > dd.UserLevels.user)
             #~ if interactive:
                 #~ js = ar.renderer.instance_handler(ar,m)
