@@ -67,7 +67,6 @@ isip_Contract = dd.resolve_model("isip.Contract")
 isip_ContractType = dd.resolve_model("isip.ContractType")
 jobs_Contract = dd.resolve_model("jobs.Contract")
 from lino_welfare.modlib.jobs.models import Contracts, ContractType, JobProvider, Job
-from lino.mixins.printable import PrintAction
 from lino.modlib.users.models import User
 #~ from lino_welfare.modlib.pcsw.models import Person
 from lino_welfare.modlib.pcsw.models import Client
@@ -602,7 +601,7 @@ Belgique""")
         menu_test('root',"""\
 - Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
 
-- Office :
+- Büro :
   
   - Mein E-Mail-Ausgang
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
@@ -610,7 +609,7 @@ Belgique""")
 
 - Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen
 
-- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen
+- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
 
 - Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
 
@@ -618,15 +617,15 @@ Belgique""")
 
 - Schuldnerberatung : Klienten, Meine Budgets
 
-- Listings : Übersicht Art.60§7-Konventionen, Benutzer und ihre Klienten, Datenkontrolle Klienten, Aktivitätsbericht, Verfügbare Begleiter
+- Listings : Benutzer und ihre Klienten, Datenkontrolle Klienten, Verfügbare Begleiter
 
 - Konfigurierung :
   
-  - Office : Meine Einfügetexte, Upload-Arten, Notizarten, Ereignisarten
+  - Büro : Meine Einfügetexte, Upload-Arten, Notizarten, Ereignisarten
   - System : Site-Parameter, Benutzer, Teams, Inhaltstypen, Hilfetexte
   - Kontakte : Länder, Orte, Sprachen, Organisationsarten, Funktionen
   - Eigenschaften : Eigenschaftsgruppen, Eigenschafts-Datentypen
-  - Kalender : Orte, Prioritäten, Gastrollen, Kalenderliste
+  - Kalender : Räume, Prioritäten, Gastrollen, Kalenderliste
   - Haushalte : Rollen in Haushalt, Haushaltsarten
   - Buchhaltung : Kontenpläne, Kontengruppen, Konten
   - ÖSHZ : Integrationsphasen, Berufe, AG-Sperrgründe, Dienste, Begleitungsbeendigungsgründe, Dispenzgründe, Klientenkontaktarten
@@ -637,7 +636,7 @@ Belgique""")
 
 - Explorer :
   
-  - Office : Einfügetexte, Uploads, E-Mail-Ausgänge, Anhänge, Postsendungen
+  - Büro : Einfügetexte, Uploads, E-Mail-Ausgänge, Anhänge, Postsendungen
   - System : Vollmachten, User Groups, Benutzer-Levels, Benutzerprofile, Änderungen
   - Kontakte : Kontaktpersonen
   - Kalender : Aufgaben, Gäste, Abonnements, Zustände, Zustände, Zustände
@@ -659,7 +658,7 @@ Belgique""")
         menu_test("100","""\
 - Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
 
-- Office :
+- Büro :
   
   - Mein E-Mail-Ausgang
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
@@ -671,11 +670,11 @@ Belgique""")
 
 - Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
 
-- Listings : Übersicht Art.60§7-Konventionen, Benutzer und ihre Klienten
+- Listings : Benutzer und ihre Klienten
 
 - Konfigurierung :
   
-  - Office : Meine Einfügetexte
+  - Büro : Meine Einfügetexte
   - Kontakte : Länder, Sprachen
 
 - Explorer :
@@ -689,7 +688,7 @@ Belgique""")
         menu_test('300',"""\
 - Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
 
-- Office :
+- Büro :
   
   - Mein E-Mail-Ausgang
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
@@ -701,7 +700,7 @@ Belgique""")
 
 - Konfigurierung :
   
-  - Office : Meine Einfügetexte
+  - Büro : Meine Einfügetexte
   - Kontakte : Länder, Sprachen
 
 - Site : Info
@@ -711,7 +710,7 @@ Belgique""")
         menu_test('200',"""\
 - Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
 
-- Office :
+- Büro :
   
   - Mein E-Mail-Ausgang
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
@@ -725,7 +724,7 @@ Belgique""")
 
 - Konfigurierung :
   
-  - Office : Meine Einfügetexte
+  - Büro : Meine Einfügetexte
   - Kontakte : Länder, Sprachen
 
 - Site : Info
